@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2010-2013 Richard Dymond (rjdymond@gmail.com)
+# Copyright 2010-2014 Richard Dymond (rjdymond@gmail.com)
 #
 # This file is part of SkoolKit.
 #
@@ -52,6 +52,7 @@ class Disassembler:
         self.defm_width = defm_width
         self.asm_hex = asm_hex
         self.asm_lower = asm_lower
+        self.defw_size = 2
         if asm_lower:
             self.hex2fmt = '${0:02x}'
             self.hex4fmt = HEX4FMT.lower()
@@ -66,21 +67,30 @@ class Disassembler:
             self.defm_inst = 'DEFM'
             self.defs_inst = 'DEFS'
             self.defw_inst = 'DEFW'
+        self.byte_formats = {
+            'b': '%{:08b}',
+            'h': self.hex2fmt,
+            'd': '{}'
+        }
+        if self.zfill:
+            self.byte_formats['d'] = '{:03d}'
+        self.word_formats = {
+            'b': '%{:016b}',
+            'h': self.hex4fmt,
+            'd': '{}'
+        }
 
-    def num_str(self, num, num_bytes=0):
-        if not self.asm_hex:
-            return str(num)
-        if num_bytes == 0:
-            if num < 10:
-                fmt = '{0}'
-            elif num < 256:
-                fmt = self.hex2fmt
+    def num_str(self, num, num_bytes=0, base=None):
+        if base not in self.byte_formats:
+            if self.asm_hex:
+                base = 'h'
             else:
-                fmt = self.hex4fmt
-        elif num_bytes == 1:
-            fmt = self.hex2fmt
-        else:
-            fmt = self.hex4fmt
+                base = 'd'
+        fmt = self.byte_formats[base]
+        if num_bytes == 0 and num < 10 and base == 'h':
+            fmt = '{}'
+        elif num > 255 or num_bytes > 1:
+            fmt = self.word_formats[base]
         return fmt.format(num)
 
     def disassemble(self, start, end=65536):
@@ -103,7 +113,7 @@ class Disassembler:
         return instructions
 
     def defb_range(self, start, end, one_line=False, sublengths=None):
-        if one_line or sublengths or end - start <= self.defb_size:
+        if one_line or (sublengths and sublengths[0][0]) or end - start <= self.defb_size:
             return [self.defb_line(start, self.snapshot[start:end], sublengths)]
         instructions = []
         data = []
@@ -115,22 +125,49 @@ class Disassembler:
                 aligned = True
                 ready = True
             if len(data) == self.defb_size or ready:
-                instructions.append(self.defb_line(i - len(data) + 1, data))
+                instructions.append(self.defb_line(i - len(data) + 1, data, sublengths))
                 data = []
                 ready = False
         if data:
-            instructions.append(self.defb_line(i - len(data) + 1, data))
+            instructions.append(self.defb_line(i - len(data) + 1, data, sublengths))
         return instructions
 
-    def defw_range(self, start, end, one_line=False):
-        if one_line:
-            words = [self.num_str(self.snapshot[i] + 256 * self.snapshot[i + 1], 2) for i in range(start, end, 2)]
-            instructions = [Instruction(start, '{0} {1}'.format(self.defw_inst, ','.join(words)), self.snapshot[start:end])]
+    def _format_word(self, value, base):
+        if base not in self.word_formats:
+            if self.asm_hex:
+                base = 'h'
+            else:
+                base = 'd'
+        return self.word_formats[base].format(value)
+
+    def _defw_items(self, data, sublengths):
+        items = []
+        if sublengths and sublengths[0][0]:
+            i = 0
+            for length, ctl in sublengths:
+                for j in range(i, i + length, 2):
+                    word = data[j] + 256 * data[j + 1]
+                    items.append(self._format_word(word, ctl))
+                i += length
         else:
-            instructions = []
-            for i in range(start, end, 2):
-                word = self.num_str(self.snapshot[i] + 256 * self.snapshot[i + 1], 2)
-                instructions.append(Instruction(i, '{0} {1}'.format(self.defw_inst, word), self.snapshot[i:i + 2]))
+            base = None
+            if sublengths:
+                base = sublengths[0][1]
+            for j in range(0, len(data), 2):
+                word = data[j] + 256 * data[j + 1]
+                items.append(self._format_word(word, base))
+        return ','.join(items)
+
+    def defw_range(self, start, end, one_line, sublengths=None):
+        if one_line:
+            step = end - start
+        else:
+            step = self.defw_size
+        instructions = []
+        for address in range(start, end, step):
+            data = self.snapshot[address:address + step]
+            defw_dir = '{} {}'.format(self.defw_inst, self._defw_items(data, sublengths))
+            instructions.append(Instruction(address, defw_dir, data))
         return instructions
 
     def defm_range(self, start, end, one_line=False, sublengths=None):
@@ -153,8 +190,13 @@ class Disassembler:
             instructions.extend(self.defm_lines(i - len(msg) + 1, msg, one_line))
         return instructions
 
-    def defs(self, start, end):
-        return [Instruction(start, '{0} {1}'.format(self.defs_inst, self.num_str(end - start)), self.snapshot[start:end])]
+    def defs(self, start, end, sublengths):
+        size = end - start
+        if sublengths:
+            items = [self.num_str(value or size, base=base) for value, base in sublengths]
+        else:
+            items = [self.num_str(size)]
+        return Instruction(start, '{} {}'.format(self.defs_inst, ','.join(items)), self.snapshot[start:end])
 
     def ignore(self, start, end):
         return [Instruction(start, '', self.snapshot[start:end])]
@@ -190,19 +232,20 @@ class Disassembler:
     def rst_arg(self, rst_address, a):
         return 'RST {0}'.format(self.num_str(rst_address, 1)), 1
 
-    def defb_items(self, data, sublengths, defb=True):
-        if self.asm_hex:
-            byte_fmt = self.hex2fmt
-        else:
-            if self.zfill:
-                byte_fmt = '{0:03d}'
+    def format_byte(self, value, base=None):
+        if base not in self.byte_formats:
+            if self.asm_hex:
+                base = 'h'
             else:
-                byte_fmt = '{0}'
-        if sublengths:
+                base = 'd'
+        return self.byte_formats[base].format(value)
+
+    def defb_items(self, data, sublengths, defb=True):
+        if sublengths and sublengths[0][0]:
             items = []
             i = 0
             for length, ctl in sublengths:
-                if ctl == 'B':
+                if ctl and ctl in 'Bbdh':
                     text = False
                 elif ctl == 'T':
                     text = True
@@ -214,10 +257,13 @@ class Disassembler:
                 if text:
                     items.append('"{0}"'.format(self.get_message(chunk)))
                 else:
-                    items.append(','.join([(byte_fmt.format(b)) for b in chunk]))
+                    items.append(','.join([(self.format_byte(b, ctl)) for b in chunk]))
                 i += length
         else:
-            items = [byte_fmt.format(b) for b in data]
+            base = None
+            if sublengths:
+                base = sublengths[0][1]
+            items = [self.format_byte(b, base) for b in data]
         return ','.join(items)
 
     def defb_dir(self, data, sublengths=None):
