@@ -292,8 +292,8 @@ class SkoolParser:
 
         self.snapshot = [0] * 65536  # 64K of Spectrum memory
         self.instructions = {}       # address -> [Instructions]
-        self.entries = {}            # address -> Routine/Data
-        self.memory_map = []         # Routines and Datas
+        self.entries = {}            # address -> SkoolEntry
+        self.memory_map = []         # SkoolEntry instances
         self.base_address = 65536
         self.header = []
         self.stack = []
@@ -393,10 +393,7 @@ class SkoolParser:
             ctl = instruction.ctl
             if ctl in DIRECTIVES:
                 desc, details, registers = self._parse_comment_block()
-                if ctl == 'c':
-                    map_entry = Routine(address, addr_str, ctl, desc, details, registers)
-                else:
-                    map_entry = Data(address, addr_str, ctl, desc, details)
+                map_entry = SkoolEntry(address, addr_str, ctl, desc, details, registers)
                 map_entry.ignoretua = self.mode.ignoretua
                 self.mode.ignoretua = False
                 map_entry.ignoredua = self.mode.ignoredua
@@ -667,7 +664,8 @@ class SkoolParser:
                     other_instructions = self.instructions.get(address)
                     if other_instructions:
                         other_entry = other_instructions[0].container
-                        if (entry != other_entry or self.mode.asm_labels) and (other_entry.is_remote() or operation.startswith(('DEFW', 'LD ')) or other_entry.is_routine()):
+                        if (not other_entry.is_ignored() and
+                            (other_entry.is_remote() or operation.startswith(('DEFW', 'LD ')) or other_entry.is_routine())):
                             instruction.set_reference(other_entry, address, addr_str)
                             if operation.startswith(('CALL', 'DJNZ', 'JP', 'JR')):
                                 other_instructions[0].add_referrer(entry)
@@ -861,12 +859,12 @@ class Mode:
     def apply_base(self, addr_str, operation):
         address = parse_int(addr_str)
         if self.decimal:
-            if address:
+            if address is not None:
                 addr_str = '{:05d}'.format(address)
             if operation:
                 operation = self.convert(operation)
         elif self.hexadecimal:
-            if address:
+            if address is not None:
                 addr_str = self.hex4fmt.format(address)
             if operation:
                 operation = self.convert(operation)
@@ -1035,14 +1033,14 @@ class Comment:
         self.text = text
 
 class SkoolEntry:
-    def __init__(self, address, addr_str=None, ctl=None, description=None, details=()):
+    def __init__(self, address, addr_str=None, ctl=None, description=None, details=(), registers=()):
         self.asm_id = ''
         self.address = address
         self.addr_str = addr_str
         self.ctl = ctl
         self.description = description
         self.details = details
-        self.registers = []
+        self.registers = [Register(prefix, name, contents) for prefix, name, contents in registers]
         self.instructions = []
         self.mid_routine_comments = {}
         self.end_comment = ()
@@ -1054,12 +1052,15 @@ class SkoolEntry:
 
     def is_routine(self):
         """Return whether the entry is a routine (code block)."""
-        return False
+        return self.ctl == 'c'
 
     def is_remote(self):
         """Return whether the entry is a remote entry."""
         return False
 
+    def is_ignored(self):
+        return self.ctl == 'i'
+
     def add_instruction(self, instruction):
         instruction.container = self
         self.instructions.append(instruction)
@@ -1082,24 +1083,12 @@ class RemoteEntry(SkoolEntry):
     def is_remote(self):
         return True
 
-class Routine(SkoolEntry):
-    def __init__(self, address, addr_str, ctl=None, description=None, details=None, registers=()):
-        SkoolEntry.__init__(self, address, addr_str, ctl, description, details)
-        for prefix, name, contents in registers:
-            self.registers.append(Register(prefix, name, contents))
-
-    def is_routine(self):
-        return True
-
 class Register:
     def __init__(self, prefix, name, contents):
         self.prefix = prefix
         self.name = name
         self.contents = contents
 
-class Data(SkoolEntry):
-    pass
-
 class TableParser:
     def parse_text(self, text, index):
         try:
