@@ -39,9 +39,7 @@ class Skool2SftTest(SkoolKitTestCase):
     def test_option_V(self):
         for option in ('-V', '--version'):
             output, error = self.run_skool2sft(option, err_lines=True, catch_exit=0)
-            self.assertEqual(len(output), 0)
-            self.assertEqual(len(error), 1)
-            self.assertEqual(error[0], 'SkoolKit {}'.format(VERSION))
+            self.assertEqual(['SkoolKit {}'.format(VERSION)], output + error)
 
     def test_option_h(self):
         self.mock(skool2sft, 'SftWriter', MockSftWriter)
