@@ -1256,6 +1256,59 @@ class SkoolParserTest(SkoolKitTestCase):
         self.assertEqual(reg_hl.name, 'HL')
         self.assertEqual(reg_hl.contents, 'The result')
 
+    def test_registers_in_non_code_blocks(self):
+        skool = '\n'.join((
+            '; Byte',
+            ';',
+            '; .',
+            ';',
+            '; A Some value',
+            'b54321 DEFB 0',
+            '',
+            '; GSB entry',
+            ';',
+            '; .',
+            ';',
+            '; B Some value',
+            'g54322 DEFB 0',
+            '',
+            '; Space',
+            ';',
+            '; .',
+            ';',
+            '; C Some value',
+            's54323 DEFS 10',
+            '',
+            '; Message',
+            ';',
+            '; .',
+            ';',
+            '; D Some value',
+            't54333 DEFM "Hi"',
+            '',
+            '; Unused code',
+            ';',
+            '; .',
+            ';',
+            '; E Some value',
+            'u54335 LD HL,12345',
+            '',
+            '; Words',
+            ';',
+            '; .',
+            ';',
+            '; H Some value',
+            'w54338 DEFW 1,2'
+        ))
+        parser = self._get_parser(skool, html=False)
+
+        for address, reg_name in ((54321, 'A'), (54322, 'B'), (54323, 'C'), (54333, 'D'), (54335, 'E'), (54338, 'H')):
+            registers = parser.entries[address].registers
+            self.assertEqual(len(registers), 1)
+            reg = registers[0]
+            self.assertEqual(reg.name, reg_name)
+            self.assertEqual(reg.contents, 'Some value')
+
     def test_snapshot(self):
         skool = '\n'.join((
             '; Test snapshot building',
@@ -1364,6 +1417,64 @@ class SkoolParserTest(SkoolKitTestCase):
         self.assertEqual(entry.asm_id, 'start')
         self.assertEqual(entry.address, 16384)
 
+    def test_references(self):
+        skool = '\n'.join((
+            '; Routine',
+            'c30000 CALL 30010',
+            ' 30003 JP NZ,30011',
+            ' 30004 LD BC,30012',
+            ' 30006 DJNZ 30013',
+            ' 30008 JR 30014',
+            '',
+            '; Routine',
+            'c30010 LD A,B',
+            ' 30011 LD A,C',
+            ' 30012 LD A,D',
+            ' 30013 LD A,E',
+            ' 30014 RET',
+            '',
+            '; Data',
+            'w30015 DEFW 30003'
+        ))
+        parser = self._get_parser(skool)
+        memory_map = parser.memory_map
+        self.assertEqual(len(memory_map), 3)
+        instructions = memory_map[0].instructions
+        self.assertEqual(len(instructions), 5)
+
+        ref_address = 30010
+        for instruction in instructions:
+            reference = instruction.reference
+            self.assertIsNotNone(reference)
+            self.assertEqual(reference.address, ref_address)
+            self.assertEqual(reference.entry.address, 30010)
+            ref_address += 1
+
+        instructions = memory_map[2].instructions
+        self.assertEqual(len(instructions), 1)
+        reference = instructions[0].reference
+        self.assertIsNotNone(reference)
+        self.assertEqual(reference.address, 30003)
+        self.assertEqual(reference.entry.address, 30000)
+
+    def test_references_to_ignored_entry(self):
+        skool = '\n'.join((
+            '; Routine',
+            'c30000 CALL 30010',
+            ' 30003 JP NZ,30010',
+            ' 30004 LD BC,30010',
+            ' 30006 DJNZ 30010',
+            ' 30008 JR 30010',
+            '',
+            '; Ignored',
+            'i30010'
+        ))
+        parser = self._get_parser(skool)
+        instructions = parser.memory_map[0].instructions
+        self.assertEqual(len(instructions), 5)
+        for instruction in instructions:
+            self.assertIsNone(instruction.reference)
+
     def test_set_directive(self):
         skool = '\n'.join((
             '; @start',
@@ -1374,7 +1485,7 @@ class SkoolParserTest(SkoolKitTestCase):
         ))
         parser = self._get_parser(skool, asm_mode=1)
         for name, value in (('prop1', '1'), ('prop2', 'abc')):
-            self.assertTrue(name in parser.properties)
+            self.assertIn(name, parser.properties)
             self.assertEqual(parser.properties[name], value)
 
     def test_set_bytes(self):
@@ -1422,6 +1533,55 @@ class SkoolParserTest(SkoolKitTestCase):
         self.assertEqual(warnings[0], 'WARNING: LD operand replaced with routine label in unsubbed operation:')
         self.assertEqual(warnings[1], '  32768 LD HL,32771 -> LD HL,DOSTUFF')
 
+    def test_instruction_addr_str_no_base(self):
+        skool = '\n'.join((
+            'b00000 DEFB 0',
+            '',
+            'c24583 LD HL,$6003',
+            '',
+            'b$600A DEFB 123'
+        ))
+        parser = self._get_parser(skool)
+        self.assertEqual(parser.get_instruction(0).addr_str, '00000')
+        self.assertEqual(parser.get_instruction(24583).addr_str, '24583')
+        self.assertEqual(parser.get_instruction(24586).addr_str, '600A')
+
+    def test_instruction_addr_str_base_10(self):
+        skool = '\n'.join((
+            'b$0000 DEFB 0',
+            '',
+            'c24583 LD HL,$6003',
+            '',
+            'b$600A DEFB 123'
+        ))
+        parser = self._get_parser(skool, base=BASE_10)
+        self.assertEqual(parser.get_instruction(0).addr_str, '00000')
+        self.assertEqual(parser.get_instruction(24583).addr_str, '24583')
+        self.assertEqual(parser.get_instruction(24586).addr_str, '24586')
+
+    def test_instruction_addr_str_base_16(self):
+        skool = '\n'.join((
+            'b00000 DEFB 0',
+            '',
+            'c24583 LD HL,$6003',
+            '',
+            'b$600A DEFB 123'
+        ))
+        parser = self._get_parser(skool, base=BASE_16)
+        self.assertEqual(parser.get_instruction(0).addr_str, '0000')
+        self.assertEqual(parser.get_instruction(24583).addr_str, '6007')
+        self.assertEqual(parser.get_instruction(24586).addr_str, '600A')
+
+    def test_instruction_addr_str_base_16_lower_case(self):
+        skool = '\n'.join((
+            'c24583 LD HL,$6003',
+            '',
+            'b$600A DEFB 123'
+        ))
+        parser = self._get_parser(skool, case=CASE_LOWER, base=BASE_16)
+        self.assertEqual(parser.get_instruction(24583).addr_str, '6007')
+        self.assertEqual(parser.get_instruction(24586).addr_str, '600a')
+
     def test_get_instruction_addr_str_no_base(self):
         skool = '\n'.join((
             'c24583 LD HL,$6003',
@@ -1554,11 +1714,11 @@ class SkoolParserTest(SkoolKitTestCase):
             'c40004 LD A,H'
         ))
         entries = self._get_parser(skool, asm_mode=1).entries
-        self.assertFalse(40000 in entries)
-        self.assertTrue(40001 in entries)
-        self.assertFalse(40002 in entries)
-        self.assertTrue(40003 in entries)
-        self.assertFalse(40004 in entries)
+        self.assertNotIn(40000, entries)
+        self.assertIn(40001, entries)
+        self.assertNotIn(40002, entries)
+        self.assertIn(40003, entries)
+        self.assertNotIn(40004, entries)
 
     def test_html_mode_label(self):
         label = 'START'
