@@ -405,9 +405,7 @@ class OptionsTest(SkoolKitTestCase):
     def test_option_V(self):
         for option in ('-V', '--version'):
             output, error = self.run_sna2skool(option, err_lines=True, catch_exit=0)
-            self.assertEqual(len(output), 0)
-            self.assertEqual(len(error), 1)
-            self.assertEqual(error[0], 'SkoolKit {}'.format(VERSION))
+            self.assertEqual(['SkoolKit {}'.format(VERSION)], output + error)
 
     def test_option_H(self):
         data = [62, 254]           # $FFFB LD A,$FE
@@ -634,7 +632,7 @@ class OptionsTest(SkoolKitTestCase):
         binfile = self._write_bin([49, 127, 50])
         for option in ('-t', '--text'):
             skool = self._write_skool('{0} {1}'.format(option, binfile), 10)
-            self.assertTrue('c65533 LD SP,12927   ; [1.2]' in skool)
+            self.assertIn('c65533 LD SP,12927   ; [1.2]', skool)
 
     def test_option_z(self):
         data = [0, 1, 2, 3, 4, 5]
