@@ -586,85 +586,6 @@ class DisassemblyTest(SkoolKitTestCase):
         ]
         self.assertEqual(exp_instructions, actual_instructions)
 
-    def test_z_directives(self):
-        snapshot = []
-        ctl = '\n'.join((
-            'z 00000',
-            '  00000,4',
-            '  00004,b4',
-            'Z 00008,d4',
-            '  00012,h8',
-            '  00020,40,b10,10,h10',
-            'Z 00060,b40,10,d10,h10',
-            '  00100,d40,b10,10,h10',
-            '  00140,h60,b10,d10,40',
-            'Z 00200,768,b256,d256,h256',
-            'i 00968'
-        ))
-        ctl_parser = CtlParser()
-        ctl_parser.parse_ctl(self.write_text_file(ctl))
-        disassembly = Disassembly(snapshot, ctl_parser, True)
-
-        entries = disassembly.entries
-        self.assertEqual(len(entries), 2)
-
-        entry = entries[0]
-        self.assertEqual(entry.address, 0)
-        instructions = entry.instructions
-        actual_instructions = [(i.address, i.operation) for i in instructions]
-        exp_instructions = [
-            (  0, 'DEFS 4'),
-            (  4, 'DEFS %00000100'),
-            (  8, 'DEFS 4'),
-            ( 12, 'DEFS 8'),
-            ( 20, 'DEFS %00001010'),
-            ( 30, 'DEFS 10'),
-            ( 40, 'DEFS $0A'),
-            ( 50, 'DEFS $0A'),
-            ( 60, 'DEFS %00001010'),
-            ( 70, 'DEFS 10'),
-            ( 80, 'DEFS $0A'),
-            ( 90, 'DEFS $0A'),
-            (100, 'DEFS %00001010'),
-            (110, 'DEFS 10'),
-            (120, 'DEFS $0A'),
-            (130, 'DEFS $0A'),
-            (140, 'DEFS %00001010'),
-            (150, 'DEFS 10'),
-            (160, 'DEFS $28'),
-            (200, 'DEFS %0000000100000000'),
-            (456, 'DEFS 256'),
-            (712, 'DEFS $0100')
-        ]
-        self.assertEqual(exp_instructions, actual_instructions)
-
-    def test_z_directives_hex(self):
-        snapshot = []
-        ctl = '\n'.join((
-            'z 00000',
-            '  00000,26,b2,d2,h2,h10,10',
-            'i 00026'
-        ))
-        ctl_parser = CtlParser()
-        ctl_parser.parse_ctl(self.write_text_file(ctl))
-        disassembly = Disassembly(snapshot, ctl_parser, True, asm_hex=True)
-
-        entries = disassembly.entries
-        self.assertEqual(len(entries), 2)
-
-        entry = entries[0]
-        self.assertEqual(entry.address, 0)
-        instructions = entry.instructions
-        actual_instructions = [(i.address, i.operation) for i in instructions]
-        exp_instructions = [
-            ( 0, 'DEFS %00000010'),
-            ( 2, 'DEFS 2'),
-            ( 4, 'DEFS 2'),
-            ( 6, 'DEFS $0A'),
-            (16, 'DEFS $0A')
-        ]
-        self.assertEqual(exp_instructions, actual_instructions)
-
 class SkoolWriterTest(SkoolKitTestCase):
     def _get_writer(self, snapshot, ctl, defb_size=8, defb_mod=1, zfill=False, defm_width=66, asm_hex=False, asm_lower=False):
         ctl_parser = CtlParser()
